@@ -369,6 +369,10 @@ def results(results : dict):
     Record the final results of an evaluation run.
     takes a dictionary of with arbitrary key names and integer, float, string, or bool values
     """
+    if not 'JIGGY_PRODUCTION_RUNTIME' in environ:
+        print("Detected development evaluation run; not storing results in Jiggyboard")
+        return
+    
     team_id  = int(environ['JIGGY_TEAM_ID'])
     board_id = int(environ['JIGGY_BOARD_ID'])
     eval_id  = int(environ['JIGGY_EVAL_ID'])
